@@ -1,10 +1,10 @@
 
 
-    -c /                     v   d dl Z d dlZd dlZd dlZdadZdZdZdZdZ	dZ
+    /c /                     v   d dl Z d dlZd dlZd dlZdadZdZdZdZdZ	dZ
  ed	            ed
             ed            ed            ed
             ed            ed            ed            ed            ej        d            G d d          Z
- G d d          Z G d d          ZdS )    Noffzoptimal,randomzv0.4.5zgmail.com, yandex.com, mail.ruz Protection version: v1.6zgmail.com,yandex.comzgmail.com,yandex.com,mail.ruzG[33m                           ___ __                        .__.__   zG[33m  ______ ____   ____    __| _//  |_  ____   _____  ____  |__|  |  zG[33m /  ___// __ \ /    \  / __ |\   __\/  _ \ /     \|__  \ |  |  |  zG[33m \___ \|  ___/|   |  \/ /_/ | |  | (  <_> )  Y Y  \/ __ \|  |  |__zG[33m/____  >\___  >___|  /\____ | |__|  \____/|__|_|  (____  /__|____/zG[33m     \/     \/     \/      \/                   \/     \/          z"[37m [>] Library name: sendtomailz"[37m [>] Developer: Misha Korzhikg333333?c            
+ G d d          Z G d d          ZdS )    Noffzoptimal,randomzv0.4.7zgmail.com, yandex.com, mail.ruz Protection version: v1.6zgmail.com,yandex.comzgmail.com,yandex.com,mail.ruzG[33m                           ___ __                        .__.__   zG[33m  ______ ____   ____    __| _//  |_  ____   _____  ____  |__|  |  zG[33m /  ___// __ \ /    \  / __ |\   __\/  _ \ /     \|__  \ |  |  |  zG[33m \___ \|  ___/|   |  \/ /_/ | |  | (  <_> )  Y Y  \/ __ \|  |  |__zG[33m/____  >\___  >___|  /\____ | |__|  \____/|__|_|  (____  /__|____/zG[33m     \/     \/     \/      \/                   \/     \/          z"[37m [>] Library name: sendtomailz"[37m [>] Developer: Misha Korzhikg333333?c            
        V    e Zd Zdededededef
 dZd ZdefdZdd
 ZdefdZd Z	d
